pub struct ScalableBloomFilter { /* private fields */ }Expand description
A scalable bloom filter implementation, based on VariantBloomFilter.
use roaring_bloom_filter::*;
let mut bf = ScalableBloomFilter::new(100, 0.001_f64);
bf.add(&10);
bf.add(&'a');
bf.add(&"a string");
bf.contains(&12);Scalable Bloom Filter(SBF)
SBF is based on variant bloom filter, consists of one or more filter. When the first filter is full, a brand new filter with more k and smaller target false positive rate would be added, extending capacity of SBF while promising target false positive rate.
Implementations
Sourceimpl ScalableBloomFilter
impl ScalableBloomFilter
Sourcepub fn from_scratch(
first_slices_length: u32,
slice_size: u64,
s: u8,
r: f64,
target_false_positive_rate: f64,
) -> ScalableBloomFilter
pub fn from_scratch( first_slices_length: u32, slice_size: u64, s: u8, r: f64, target_false_positive_rate: f64, ) -> ScalableBloomFilter
Create an empty scalable bloom filter from scratch.
Generally, user should not use this initializer directly. Promise the limitation on yourself:
- 0 < k <= u32::MAX
- 0 < m <= u32::MAX
- s = 2 or 4
- 0.8 <= r <= 0.9
- 0 < f < 1
Sourcepub fn new(first_max_size: u64, target_false_positive: f64) -> impl BloomFilter
pub fn new(first_max_size: u64, target_false_positive: f64) -> impl BloomFilter
Create an empty bloom filter with max element’s size for the first filter and false positive rate. The crate would calculate the best buckets length and bucket size, and make s = 4, r = 0.9.